package com.chelvc.framework.database.context;

import java.io.Serializable;
import java.lang.reflect.Field;

import com.baomidou.mybatisplus.core.metadata.TableFieldInfo;
import com.chelvc.framework.database.annotation.Sensitive;
import lombok.Getter;
import lombok.NonNull;
import org.apache.ibatis.type.TypeHandler;
import org.apache.ibatis.type.UnknownTypeHandler;

/**
 * 字段上下文对象
 *
 * @author Woody
 * @date 2024/6/10
 */
@Getter
public class TableFieldContext implements Serializable {
    private final boolean sensitive;
    private final TableFieldInfo info;

    public TableFieldContext(@NonNull TableFieldInfo info) {
        this.info = info;
        this.sensitive = info.getField().isAnnotationPresent(Sensitive.class);
    }

    /**
     * 获取属性类型
     *
     * @return 对象类型
     */
    public Class<?> getType() {
        return this.info.getPropertyType();
    }

    /**
     * 获取字段对象
     *
     * @return 字段对象实例
     */
    public Field getField() {
        return this.info.getField();
    }

    /**
     * 获取字段名称
     *
     * @return 字段名称
     */
    public String getColumn() {
        return this.info.getColumn();
    }

    /**
     * 获取属性名称
     *
     * @return 属性名称
     */
    public String getProperty() {
        return this.info.getProperty();
    }

    /**
     * 获取类型处理器实例
     *
     * @return 类型处理器实例
     */
    public TypeHandler<?> getHandler() {
        Class<? extends TypeHandler<?>> type = this.info.getTypeHandler();
        return type == null || type == UnknownTypeHandler.class ? null : DatabaseContextHolder.getTypeHandler(type);
    }
}
